
__version__ = '0.0.5'

__title__ = 'repovisor'

__summary__ = 'A tool for managing many repositories and creating daily reports'

__uri__ = 'https://github.com/gjcooper/repovisor'

__license__ = 'BSD'

__author__ = 'Gavin Cooper'

__email__ = 'gjcooper@gmail.com'
